@@ -21,12 +21,12 @@ require(RDCOMClient)
   cat("NOTICE:\n")
   cat("o mimR is available on Windows platforms only \n")
   cat("o The current version of mimR requires that \n")
-  cat("  - R version 2.0.1 or later is used\n")
+  cat("  - R version 2.1.1 or later is used\n")
   cat("  - MIM version 3.2 or later is installed on the computer\n")
   cat("    MIM can be downloaded from http://www.hypergraph.dk.\n")
   cat("  - the R package RDCOMClient package is installed.\n")
-  cat("    The RDCOMClient package can be downloaded from \n")
-  cat("    http://www.omegahat.org/download/R/packages/Windows/R-2.0.0/\n")
+  cat("o mimR will automatically start the MIM program if not already running. \n")
+  cat("  However, mimR sometimes runs more smoothly if the user starts MIM manually.\n")
   cat("\n  For more information type ?mimR\n")
   cat("-------------------------------------------------------------\n")
   return(invisible(0))
